#!/bin/ksh

# * Licensed Materials - Property of IBM
# * 5724-L68, 5724-L69
# * (C) Copyright IBM Corp. 2007 - All Rights Reserved.
# * US Government Users Restricted Rights - Use, duplication or disclosure
# * restricted by GSA ADP Schedule Contract with IBM Corp.

## Step 1: Verify input params and give usage

if [ $# -lt 5 -o $# -gt 11 ]
then 
echo The script needs the following parameters
echo 1. Database user name
echo 2. Database user password
echo 3. Cutoff date YYYYMMDD
echo 4. Destination for the archive
echo 5. Partner Name
echo 6. Package Name
echo 7. Package Version
echo 8. Protocol Name
echo 9. Protocol Version
echo 10. Process Name
echo 11. Process Version

echo 'USAGE  : ./bcgDBNonRepExport.sh <userid> <password> <cutoff date YYYYMMDD> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]' 

echo 'SAMPLE : ./bcgDBNonRepExport db2inst1 pa55word 20050318 /tmp/archive  partnerA  N/A \* None \* EDI-X12 \* '

exit 1
fi

## Step2: Initialise the variables and take required input parameters
nosofparams=$#
package='packagename'
packageversion='packagever'
protocol='protocolname'
protocolversion='protocolver'
process='processname'
processversion='processver'

userid=$1
shift
password=$1
shift
cutoffdate=$1

shift
archivedest=$1
shift
partnervar=$1

## Step3: Take and Manipulate optional input parameters. If the input parm is * then set it to column name
##        for easier SQL otherwise put quotes around it.

if test "$partnervar" = "*"
	then
		partnervar='partnername'
	else
		partnervar=\'$partnervar\'
fi

if test $nosofparams -gt 5
	then
		shift
		package=$1
		if test "$package" = "*"
			then
				package='packagename'
			else
				package=\'$package\'
		fi
fi

if test $nosofparams -gt 6
	then
		shift
		packageversion=$1
		if test "$packageversion" = "*"
			then
				packageversion='packagever'
			else
				packageversion=\'$packageversion\'
		fi
fi

if test $nosofparams -gt 7
	then
		shift
		protocol=$1
		if test "$protocol" = "*"
			then
				protocol='protocolname'
			else
				protocol=\'$protocol\'
		fi
fi

if test $nosofparams -gt 8
	then
		shift
		protocolversion=$1
		if test "$protocolversion" = "*"
			then
				protocolversion='protocolver'
			else
				protocolversion=\'$protocolversion\'
		fi
fi

if test $nosofparams -gt 9
	then
		shift
		process=$1
		if test "$process" = "*"
			then
				process='processname'
			else
				process=\'$process\'
		fi
fi

if test $nosofparams -gt 10
	then
		shift
		processversion=$1
		if test "$processversion" = "*"
			then
				processversion='processver'
			else
				processversion=\'$processversion\'
		fi
fi

## Convert input date format of YYYYMMDD to DB2 format of YYYY-MM-DD and do the validations as well
if test ${#cutoffdate} -lt 8
then
	echo Input date format not right. It should be YYYYMMDD
      echo 'USAGE  : ./bcgDBNonRepExport.sh <userid> <password> <cutoff date YYYYMMDD> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]' 
      echo 'SAMPLE : ./bcgDBNonRepExport db2inst1 pa55word 20050318 /tmp/archive  partnerA  N/A \* None \* EDI-X12 \* '
	exit 1
fi
set `echo $cutoffdate | cut -c1-4`
cutoffdateyy=$1
if test $cutoffdateyy -lt 2000
then
	echo Input date format not right. It should be YYYYMMDD
      echo 'USAGE  : ./bcgDBNonRepExport.sh <userid> <password> <cutoff date YYYYMMDD> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]' 
      echo 'SAMPLE : ./bcgDBNonRepExport db2inst1 pa55word 20050318 /tmp/archive  partnerA  N/A \* None \* EDI-X12 \* '
	exit 1
fi
set `echo $cutoffdate | cut -c5,6`
cutoffdatemm=$1
if test $cutoffdatemm -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo 'USAGE  : ./bcgDBNonRepExport.sh <userid> <password> <cutoff date YYYYMMDD> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]' 
      echo 'SAMPLE : ./bcgDBNonRepExport db2inst1 pa55word 20050318 /tmp/archive  partnerA  N/A \* None \* EDI-X12 \* '
	exit 1
fi

if test $cutoffdatemm -gt 12
then
	echo Input date format not right. It should be YYYYMMDD
      echo 'USAGE  : ./bcgDBNonRepExport.sh <userid> <password> <cutoff date YYYYMMDD> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]' 
      echo 'SAMPLE : ./bcgDBNonRepExport db2inst1 pa55word 20050318 /tmp/archive  partnerA  N/A \* None \* EDI-X12 \* '
	exit 1
fi
set `echo $cutoffdate | cut -c7,8`
cutoffdatedd=$1
if test $cutoffdatedd -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo 'USAGE  : ./bcgDBNonRepExport.sh <userid> <password> <cutoff date YYYYMMDD> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]' 
      echo 'SAMPLE : ./bcgDBNonRepExport db2inst1 pa55word 20050318 /tmp/archive  partnerA  N/A \* None \* EDI-X12 \* '
	exit 1
fi

if test $cutoffdatedd -gt 31
then
	echo Input date format not right. It should be YYYYMMDD
      echo 'USAGE  : ./bcgDBNonRepExport.sh <userid> <password> <cutoff date YYYYMMDD> <archive destination> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]' 
      echo 'SAMPLE : ./bcgDBNonRepExport db2inst1 pa55word 20050318 /tmp/archive  partnerA  N/A \* None \* EDI-X12 \* '
	exit 1
fi

cutoffdateuse=${cutoffdateyy}-${cutoffdatemm}-${cutoffdatedd}


##Step 4 Create the dest directory, connect to database and export

mkdir -p $archivedest/$cutoffdate

echo Trying to connect to the database. Please Wait ...

db2 connect to $DB_NAME$ user $userid using $password

if test $? -eq 0 
then

echo Connected to database and Export in Progress. Please Wait ...

##db2 export to $archivedest/$cutoffdate/bcgDBNonRepExport.ixf of ixf messages $archivedest/$cutoffdate/bcgDBNonRepExport.txt lobs to $2/$1 lobfile lobs1, lobs2 modified by lobsinfile select \* from lg_msg_archive where createdate \< timestamp\(\'$cutoffdateuse-00.00.00.000000\'\) and partnername = $partnervar and packagename= $package and packagever= $packageversion and protocolname = $protocol and protocolver = $protocolversion and processname= $process and processver = $processversion
##db2 export to $archivedest/$cutoffdate/bcgDBNonRepExport.del of del lobs to $archivedest/$cutoffdate lobfile lobs1, lobs2 modified by lobsinfile select \* from lg_msg_archive where createdate \< timestamp\(\'$cutoffdateuse-00.00.00.000000\'\) and partnername = $partnervar and packagename= $package and packagever= $packageversion and protocolname = $protocol and protocolver = $protocolversion and processname= $process and processver = $processversion
db2 export to $archivedest/$cutoffdate/bcgDBNonRepExport.ixf of ixf lobs to $archivedest/$cutoffdate lobfile lobs1, lobs2 modified by lobsinfile select \* from lg_msg_archive where createdate \< timestamp\(\'$cutoffdateuse-00.00.00.000000\'\) and partnername = $partnervar and packagename= $package and packagever= $packageversion and protocolname = $protocol and protocolver = $protocolversion and processname= $process and processver = $processversion

if test $? -gt 0
then
			echo The Non Rep Export failed to run
		       else 
		        echo The Non Rep Export program ran successfully
fi

##db2 export to $2/$1/certarchive.del of del lobs to $2/$1 lobfile lobs1, lobs2 modified by lobsinfile select \* from lg_cert_archive where createdate \< timestamp\(\'$1-00.00.00.000000\'\)

db2 +o connect reset

exit 0
else
echo Failed to connect to database.
exit 1
fi
