#!/bin/ksh

# * Licensed Materials - Property of IBM
# * 5724-L68, 5724-L69
# * (C) Copyright IBM Corp. 2007 - All Rights Reserved.
# * US Government Users Restricted Rights - Use, duplication or disclosure
# * restricted by GSA ADP Schedule Contract with IBM Corp.

## Step 1: Verify input params and give usage

if [ $# -lt 4 -o $# -gt 10 ]
then 
echo The script needs the following parameters
echo 1. Database user name
echo 2. Database user password
echo 3. Cutoff date YYYYMMDD
echo 4. Partner Name
echo 5. Package Name 
echo 6. Package Version
echo 7. Protocol Name
echo 8. Protocol Version
echo 9. Process Name
echo 10. Process Version


echo "USAGE  : bcgNonRepMaintenance <userid> <password> <cutoff date YYYYMMDD> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"

echo "SAMPLE : bcgNonRepMaintenance db2inst1 pa55word 20050318 partnerA  N/A \* None \* EDI-X12 \* "

exit 1
fi

## Step 2: Input validations
nosofparams=$#
package=allO0oxyz
packageversion=allO0oxyz
protocol=allO0oxyz
protocolversion=allO0oxyz
process=allO0oxyz
processversion=allO0oxyz

userid=$1
shift
password=$1
shift
cutoffdate=$1
shift
partnervar=$1
if test "$partnervar" = "*"
	then
		partnervar='allO0oxyz'
fi

if test $nosofparams -gt 4
	then
		shift
		package=$1
		if test "$package" = "*"
			then
				package='allO0oxyz'
		fi
fi

if test $nosofparams -gt 5
	then
		shift
		packageversion=$1
		if test "$packageversion" = "*"
			then
				packageversion='allO0oxyz'
		fi
fi

if test $nosofparams -gt 6
	then
		shift
		protocol=$1
		if test "$protocol" = "*"
			then
				protocol='allO0oxyz'
		fi
fi

if test $nosofparams -gt 7
	then
		shift
		protocolversion=$1
		if test "$protocolversion" = "*"
			then
				protocolversion='allO0oxyz'
		fi
fi

if test $nosofparams -gt 8
	then
		shift
		process=$1
		if test "$process" = "*"
			then
				process='allO0oxyz'
		fi
fi

if test $nosofparams -gt 9
	then
		shift
		processversion=$1
		if test "$processversion" = "*"
			then
				processversion='allO0oxyz'
		fi
fi

## Convert input date format of YYYYMMDD to DB2 format of YYYY-MM-DD and do the validations as well
if test ${#cutoffdate} -lt 8
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgNonRepMaintenance <userid> <password> <cutoff date YYYYMMDD> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgNonRepMaintenance db2inst1 pa55word 20050318 partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi
set `echo $cutoffdate | cut -c1-4`
cutoffdateyy=$1
if test $cutoffdateyy -lt 2000
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgNonRepMaintenance <userid> <password> <cutoff date YYYYMMDD> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgNonRepMaintenance db2inst1 pa55word 20050318 partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi
set `echo $cutoffdate | cut -c5,6`
cutoffdatemm=$1
if test $cutoffdatemm -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgNonRepMaintenance <userid> <password> <cutoff date YYYYMMDD> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgNonRepMaintenance db2inst1 pa55word 20050318 partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi

if test $cutoffdatemm -gt 12
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgNonRepMaintenance <userid> <password> <cutoff date YYYYMMDD> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgNonRepMaintenance db2inst1 pa55word 20050318 partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi
set `echo $cutoffdate | cut -c7,8`
cutoffdatedd=$1
if test $cutoffdatedd -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgNonRepMaintenance <userid> <password> <cutoff date YYYYMMDD> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgNonRepMaintenance db2inst1 pa55word 20050318 partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi
if test $cutoffdatedd -gt 31
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgNonRepMaintenance <userid> <password> <cutoff date YYYYMMDD> <partner> [package] [package version] [protocol] [protocol version] [process] [process version]"
      echo "SAMPLE : bcgNonRepMaintenance db2inst1 pa55word 20050318 partnerA  N/A \* None \* EDI-X12 \* "
	exit 1
fi

cutoffdateuse=${cutoffdateyy}-${cutoffdatemm}-${cutoffdatedd}


echo Trying to connect to the database. Please Wait ...

db2 connect to $DB_NAME$ user $userid using $password

if test $? -eq 0 
then

echo Connected to database and NonRep Maintenance in Progress. Please Wait ...

db2 +o "call AR_NONREP_MAINTENANCE('$cutoffdateuse','$partnervar', '$package', '$packageversion', '$protocol', '$protocolversion', '$process', '$processversion','$userid')"

if test $? -gt 0
      then
			echo The NonRep Maintenance procedure failed to run
	    else 
		  echo The NonRep Maintenance program ran successfully
fi
		
db2 +o connect reset
exit 0
else
echo Failed to connect to database.
exit 1
fi
