#!/bin/ksh

# * Licensed Materials - Property of IBM
# * 5724-L68, 5724-L69
# * (C) Copyright IBM Corp. 2007 - All Rights Reserved.
# * US Government Users Restricted Rights - Use, duplication or disclosure
# * restricted by GSA ADP Schedule Contract with IBM Corp.

## Step 1: Verify input params and give usage

if [ $# -lt 3 ]
then 
echo The script needs the following parameters
echo 1. Database user name
echo 2. Database user password
echo 3. Cutoff date YYYYMMDD

echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"

echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "

exit 1
fi

userid=$1
shift
password=$1
shift
cutoffdate=$1

## Convert input date format of YYYYMMDD to DB2 format of YYYY-MM-DD and do the validations as well
if test ${#cutoffdate} -lt 8
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
set `echo $cutoffdate | cut -c1-4`
cutoffdateyy=$1
if test $cutoffdateyy -lt 2000
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
set `echo $cutoffdate | cut -c5,6`
cutoffdatemm=$1
if test $cutoffdatemm -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi

if test $cutoffdatemm -gt 12
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
set `echo $cutoffdate | cut -c7,8`
cutoffdatedd=$1
if test $cutoffdatedd -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
if test $cutoffdatedd -gt 31
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi

cutoffdateuse=${cutoffdateyy}-${cutoffdatemm}-${cutoffdatedd}

echo Trying to connect to the database. Please Wait ...

db2 connect to $DB_NAME$ user $userid using $password

if test $? -eq 0 
then

echo Connected to database and Header Purge in Progress. Please Wait ...

db2 +o "call AR_PURGE_HEADERS('$cutoffdateuse')"

if test $? -gt 0
      then
			echo The purge procedure failed to run
	    else 
		        db2 +o "insert into lg_archiveinfo(actionname, cutoffdate) values('HEADER PURGE','$cutoffdateuse')"
		        echo The Header Purge program ran successfully
fi
		
db2 +o connect reset
exit 0
else
echo Failed to connect to database.
exit 1
fi
