#!/bin/ksh

# * Licensed Materials - Property of IBM
# * 5724-L68, 5724-L69
# * (C) Copyright IBM Corp. 2007 - All Rights Reserved.
# * US Government Users Restricted Rights - Use, duplication or disclosure
# * restricted by GSA ADP Schedule Contract with IBM Corp.

## Step 1: Verify input params and give usage

if [ $# -lt 3 ]
then 
echo The script needs the following parameters
echo 1. Database user name
echo 2. Database user password
echo 3. Cutoff date YYYYMMDD

echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"

echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "

exit 1
fi

userid=$1
shift
password=$1
shift
cutoffdate=$1

## Do the date validations as well
if test ${#cutoffdate} -lt 8
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
set `echo $cutoffdate | cut -c1-4`
cutoffdateyy=$1
if test $cutoffdateyy -lt 2000
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
set `echo $cutoffdate | cut -c5,6`
cutoffdatemm=$1
if test $cutoffdatemm -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
if test $cutoffdatemm -gt 12
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
set `echo $cutoffdate | cut -c7,8`
cutoffdatedd=$1
if test $cutoffdatedd -lt 1
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi
if test $cutoffdatedd -gt 31
then
	echo Input date format not right. It should be YYYYMMDD
      echo "USAGE  : bcgPurgeMaintenance <userid> <password> <cutoff date YYYYMMDD>"
      echo "SAMPLE : bcgPurgeMaintenance db2admin pa55word 20050318 "
	exit 1
fi

cutoffdateuse=${cutoffdateyy}-${cutoffdatemm}-${cutoffdatedd}
echo Trying to connect to the database. Please Wait ...

sqlfile=/tmp/execpurgesql.sql

if test -f $sqlfile 
then
	rm -f $sqlfile
fi

echo set feedback off >>$sqlfile
echo "execute AR_PURGE_HEADERS('$cutoffdateuse');" >> $sqlfile
echo "insert into lg_archiveinfo(archiveid, actionname, cutoffdate) values(LG_ARCHIVEINFO_SEQ.nextval,'HEADER PURGE',to_date('$cutoffdate','YYYYMMDD'));" >> $sqlfile
echo set feedback on >>$sqlfile

echo exit >> $sqlfile

$ORACLE_HOME/bin/sqlplus -L -S $userid/$password@$DB_NAME$ @$sqlfile


if test $? -gt 0 
      then
			echo The Purge Header program failed to run
			else     
		   echo The Purge Header program ran successfully
fi

if test -f $sqlfile 
then
	rm -f $sqlfile
fi
exit 0
